<?php
/*
 * This file is part of Gutenberg PHP Block.
 *
 * Gutenberg PHP Block is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Gutenberg PHP Block is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Gutenberg PHP Block.  If not, see <https://www.gnu.org/licenses/>.
 */

declare( strict_types=1 );

namespace GutenbergPhpBlock;

use Throwable;

class Bootstrap {
	public function __construct( string $plugin_file ) {
		$this->setupTranslation( $plugin_file );
		$this->loadClasses( $plugin_file );
	}

	private function setupTranslation( string $plugin_file ): void {
		load_plugin_textdomain(
			'gutenberg-php-block',
			false,
			dirname( plugin_basename( $plugin_file ) ) . '/languages'
		);
	}

	private function loadClasses( string $plugin_file ): void {
		$classes = [
			PhpBlock::class, // phpcs:ignore ImportDetection.Imports.RequireImports.Symbol
		];
		foreach ( $classes as $class ) {
			try {
				new $class( $plugin_file ); // phpcs:ignore NeutronStandard.Functions.VariableFunctions.VariableFunction
			} catch ( Throwable $e ) {
				$title = __( 'Gutenberg PHP Block Initialization Failed', 'gutenberg-php-block' );
				$message = sprintf(
				// translators: %1$s is class name; %2$s is exception message.
					__( '<p>Could not load class "%1$s"</p><p><strong>Error</strong>: %2$s</p>', 'gutenberg-php-block' ),
					$class,
					$e->getMessage()
				);
				wp_die( $message, $title );
			}
		}
	}
}
