<?php
declare( strict_types=1 );

namespace GutenbergPhpBlock;

use Throwable;
use function register_block_type;
use function wp_set_script_translations;

class PhpBlock {
	private string $plugin_file;

	public function __construct( string $plugin_file ) {
		$this->plugin_file = $plugin_file;
		add_action( 'init', [ $this, 'register_block' ] );
	}

	public function register_block() {
		/* @noinspection PhpIncludeInspection */
		$asset = include plugin_dir_path( $this->plugin_file ) . 'build/index.asset.php';

		wp_register_script(
			'gutenberg-php-block',
			plugins_url( 'build/index.js', $this->plugin_file ),
			$asset['dependencies'],
			$asset['version'],
			true
		);

		wp_set_script_translations(
			'gutenberg-php-block',
			'gutenberg-php-block',
			plugin_dir_path( $this->plugin_file ) . 'languages'
		);

		wp_register_style(
			'gutenberg-php-block',
			plugins_url( 'build/index.css', $this->plugin_file ),
			[],
			$asset['version'],
		);

		register_block_type(
			'tandem/php',
			[
				'editor_script' => 'gutenberg-php-block',
				'editor_style' => 'gutenberg-php-block',
				'render_callback' => [ $this, 'render_block' ],
			]
		);
	}

	public function render_block( array $attributes ): string {
		ob_start();
		try {
			eval( '?>' . $attributes['text'] . '<?php' ); // phpcs:ignore Squiz.PHP.Eval.Discouraged
		} catch ( Throwable $e ) {
			error_log( 'Failed to execute PHP code: ' . $e->getMessage() );
		}
		$content = ob_get_contents();
		ob_end_clean();

		return do_shortcode( $content );
	}
}
